# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""update std_cms_imaging state machine for QA

Revision ID: 41a10866241c
Revises: 5ba576734f3b
Create Date: 2022-01-25 14:21:15.079550

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "41a10866241c"
down_revision = "5ba576734f3b"
branch_labels = None
depends_on = None


def upgrade():
    # Update std_cms_imaging state machine for QA
    imaging_st_machine_to_qa_sql = """
    UPDATE capability_state_machines SET machine_type = 'single_qa'
    WHERE capability_name = 'std_cms_imaging';
    """
    op.execute(imaging_st_machine_to_qa_sql)

    # Simplify std_calibration's associated_workflows JSON
    # (there's currently no need to specify multiple workflow names)
    simplify_cal_assoc_wfs_json_sql = """
    UPDATE capability_state_machines SET associated_workflows = '{"workflow_name": "std_calibration"}'
    WHERE capability_name = 'std_calibration';
    """
    op.execute(simplify_cal_assoc_wfs_json_sql)


def downgrade():
    # Update std_cms_imaging state machine for QA
    undo_imaging_st_machine_to_qa_sql = """
    UPDATE capability_state_machines SET machine_type = 'simple'
    WHERE capability_name = 'std_cms_imaging';
    """
    op.execute(undo_imaging_st_machine_to_qa_sql)

    # Simplify std_calibration's associated_workflows JSON
    # (there's currently no need to specify multiple workflow names)
    undo_simplify_cal_assoc_wfs_json_sql = """
    UPDATE capability_state_machines
    SET associated_workflows = '{"workflow_name": "std_calibration", "qa_fail_workflow_name": "qa_fail", "qa_pass_workflow_name": "ingest_cal"}'
    WHERE capability_name = 'std_calibration';
    """
    op.execute(undo_simplify_cal_assoc_wfs_json_sql)
